@@ -43,6 +43,7 @@ ARGUMENT_RENAMES = {
     'codepipeline.create-custom-action-type.version': 'action-version',
     'codepipeline.delete-custom-action-type.version': 'action-version',
     'kinesisanalytics.add-application-output.output': 'application-output',
+    'kinesisanalyticsv2.add-application-output.output': 'application-output',
     'route53.delete-traffic-policy.version': 'traffic-policy-version',
     'route53.get-traffic-policy.version': 'traffic-policy-version',
     'route53.update-traffic-policy-comment.version': 'traffic-policy-version',
@@ -51,6 +52,8 @@ ARGUMENT_RENAMES = {
     'route53domains.view-billing.start': 'start-time',
     'route53domains.view-billing.end': 'end-time',
     'apigateway.create-rest-api.version': 'api-version',
+    'apigatewayv2.create-api.version': 'api-version',
+    'apigatewayv2.update-api.version': 'api-version',
     'pinpoint.get-campaign-version.version': 'campaign-version',
     'pinpoint.get-segment-version.version': 'segment-version',
     'stepfunctions.send-task-success.output': 'task-output',
@@ -71,6 +74,7 @@ ARGUMENT_RENAMES = {
     'mobile.create-project.region': 'project-region',
     'rekognition.create-stream-processor.output': 'stream-processor-output',
     'eks.create-cluster.version': 'kubernetes-version',
+    'eks.update-cluster-version.version': 'kubernetes-version',
 }
 
 # Same format as ARGUMENT_RENAMES, but instead of renaming the arguments,
@@ -86,6 +90,22 @@ HIDDEN_ALIASES = {
     'storagegateway.describe-cached-iscsi-volumes.volume-arns': 'volume-ar-ns',
     'storagegateway.describe-stored-iscsi-volumes.volume-arns': 'volume-ar-ns',
     'route53domains.view-billing.start-time': 'start',
+    # These come from the xform_name() changes that no longer separates words
+    # by numbers.
+    'deploy.create-deployment-group.ec2-tag-set': 'ec-2-tag-set',
+    'deploy.list-application-revisions.s3-bucket': 's-3-bucket',
+    'deploy.list-application-revisions.s3-key-prefix': 's-3-key-prefix',
+    'deploy.update-deployment-group.ec2-tag-set': 'ec-2-tag-set',
+    'iam.enable-mfa-device.authentication-code1': 'authentication-code-1',
+    'iam.enable-mfa-device.authentication-code2': 'authentication-code-2',
+    'iam.resync-mfa-device.authentication-code1': 'authentication-code-1',
+    'iam.resync-mfa-device.authentication-code2': 'authentication-code-2',
+    'importexport.get-shipping-label.street1': 'street-1',
+    'importexport.get-shipping-label.street2': 'street-2',
+    'importexport.get-shipping-label.street3': 'street-3',
+    'lambda.publish-version.code-sha256': 'code-sha-256',
+    'lightsail.import-key-pair.public-key-base64': 'public-key-base-64',
+    'opsworks.register-volume.ec2-volume-id': 'ec-2-volume-id',
 }
 
 
